==> igniteui-react-core-18.2.0-beta.1.tgz: package/esm5/lib/NativeUIPopup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { NativeUIPopupAnimationType_$type } from "./NativeUIPopupAnimationType";
import { NativeUIPopupPointerPosition_$type } from "./NativeUIPopupPointerPosition";
import { typeGetValue, enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIPopup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIPopup, _super);
    function NativeUIPopup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.br = null;
        _this.bp = null;
        return _this;
    }
    Object.defineProperty(NativeUIPopup.prototype, "bn", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "by", {
        get: function () {
            return this.ae(22);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bu", {
        get: function () {
            return this.ae(25);
        },
        set: function (a) {
            this.a0(25, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b0", {
        get: function () {
            return typeGetValue(this.ae(26));
        },
        set: function (a) {
            this.a0(26, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bv", {
        get: function () {
            return this.ae(39);
        },
        set: function (a) {
            this.a0(39, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bo", {
        get: function () {
            return EnumUtil.getEnumValue(NativeUIPopupAnimationType_$type, this.ae(35));
        },
        set: function (a) {
            this.a0(35, enumGetBox(NativeUIPopupAnimationType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b6", {
        get: function () {
            return this.ae(23);
        },
        set: function (a) {
            this.a0(23, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bz", {
        get: function () {
            return this.ae(17);
        },
        set: function (a) {
            this.a0(17, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIPopup.prototype.get_u = function () {
        return this.ae(36);
    };
    NativeUIPopup.prototype.set_u = function (a) {
        this.a0(36, a);
    };
    Object.defineProperty(NativeUIPopup.prototype, "bw", {
        get: function () {
            return this.ae(37);
        },
        set: function (a) {
            this.a0(37, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b1", {
        get: function () {
            return typeGetValue(this.ae(40));
        },
        set: function (a) {
            this.a0(40, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bx", {
        get: function () {
            return this.ae(41);
        },
        set: function (a) {
            this.a0(41, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bt", {
        get: function () {
            return EnumUtil.getEnumValue(NativeUIPopupPointerPosition_$type, this.ae(43));
        },
        set: function (a) {
            this.a0(43, enumGetBox(NativeUIPopupPointerPosition_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b7", {
        get: function () {
            return this.ae(42);
        },
        set: function (a) {
            this.a0(42, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bs", {
        get: function () {
            return this.br;
        },
        set: function (a) {
            var b = this.br;
            this.br = a;
            if (this.br != null) {
                this.an(5, this.br);
            }
            else {
                this.ay(5, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bq", {
        get: function () {
            return this.bp;
        },
        set: function (a) {
            var b = this.bp;
            this.bp = a;
            if (this.bp != null) {
                this.an(6, this.bp);
            }
            else {
                this.ay(6, b);
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIPopup.prototype.b5 = function (a, b, c) {
        this.bn.showRelativeToExclusionRect(this.ak, a, b, c);
    };
    NativeUIPopup.prototype.b2 = function () {
        this.bn.close(this.ak);
    };
    NativeUIPopup.prototype.b3 = function () {
        this.bn.notifyContentSizeChanged(this.ak);
    };
    NativeUIPopup.prototype.b4 = function (a) {
        this.bn.notifyExclusionRectChanged(this.ak, a);
    };
    NativeUIPopup.$t = markType(NativeUIPopup, 'NativeUIPopup', NativeUIContainer.$);
    return NativeUIPopup;
}(NativeUIContainer));
export { NativeUIPopup };

==> igniteui-react-core-18.3.2-beta.1.tgz: package/esm5/lib/NativeUIPopup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIContainer } from "./NativeUIContainer";
import { NativeUIPopupAnimationType_$type } from "./NativeUIPopupAnimationType";
import { NativeUIPopupPointerPosition_$type } from "./NativeUIPopupPointerPosition";
import { typeGetValue, enumGetBox, EnumUtil, markType } from "./type";
/**
 * @hidden
 */
var NativeUIPopup = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIPopup, _super);
    function NativeUIPopup() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.br = null;
        _this.bp = null;
        return _this;
    }
    Object.defineProperty(NativeUIPopup.prototype, "bn", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b0", {
        get: function () {
            return this.ae(22);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bz", {
        get: function () {
            return this.ae(59);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bw", {
        get: function () {
            return this.ae(60);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bu", {
        get: function () {
            return this.ae(25);
        },
        set: function (a) {
            this.a0(25, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b3", {
        get: function () {
            return typeGetValue(this.ae(26));
        },
        set: function (a) {
            this.a0(26, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bv", {
        get: function () {
            return this.ae(39);
        },
        set: function (a) {
            this.a0(39, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bo", {
        get: function () {
            return EnumUtil.getEnumValue(NativeUIPopupAnimationType_$type, this.ae(35));
        },
        set: function (a) {
            this.a0(35, enumGetBox(NativeUIPopupAnimationType_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b9", {
        get: function () {
            return this.ae(23);
        },
        set: function (a) {
            this.a0(23, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b1", {
        get: function () {
            return this.ae(17);
        },
        set: function (a) {
            this.a0(17, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIPopup.prototype.get_u = function () {
        return this.ae(36);
    };
    NativeUIPopup.prototype.set_u = function (a) {
        this.a0(36, a);
    };
    Object.defineProperty(NativeUIPopup.prototype, "bx", {
        get: function () {
            return this.ae(37);
        },
        set: function (a) {
            this.a0(37, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b4", {
        get: function () {
            return typeGetValue(this.ae(40));
        },
        set: function (a) {
            this.a0(40, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "by", {
        get: function () {
            return this.ae(41);
        },
        set: function (a) {
            this.a0(41, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bt", {
        get: function () {
            return EnumUtil.getEnumValue(NativeUIPopupPointerPosition_$type, this.ae(43));
        },
        set: function (a) {
            this.a0(43, enumGetBox(NativeUIPopupPointerPosition_$type, a));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "ca", {
        get: function () {
            return this.ae(42);
        },
        set: function (a) {
            this.a0(42, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "b2", {
        get: function () {
            return this.ae(61);
        },
        set: function (a) {
            this.a0(61, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bs", {
        get: function () {
            return this.br;
        },
        set: function (a) {
            var b = this.br;
            this.br = a;
            if (this.br != b) {
                if (b != null) {
                    this.ay(5, b);
                }
                if (this.br != null) {
                    this.an(5, this.br);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIPopup.prototype, "bq", {
        get: function () {
            return this.bp;
        },
        set: function (a) {
            var b = this.bp;
            this.bp = a;
            if (this.bp != b) {
                if (b != null) {
                    this.ay(6, b);
                }
                if (this.bp != null) {
                    this.an(6, this.bp);
                }
            }
        },
        enumerable: false,
        configurable: true
    });
    NativeUIPopup.prototype.b8 = function (a, b, c) {
        this.bn.showRelativeToExclusionRect(this.ak, a, b, c);
    };
    NativeUIPopup.prototype.b5 = function () {
        this.bn.close(this.ak);
    };
    NativeUIPopup.prototype.b6 = function () {
        this.bn.notifyContentSizeChanged(this.ak);
    };
    NativeUIPopup.prototype.b7 = function (a) {
        this.bn.notifyExclusionRectChanged(this.ak, a);
    };
    NativeUIPopup.$t = markType(NativeUIPopup, 'NativeUIPopup', NativeUIContainer.$);
    return NativeUIPopup;
}(NativeUIContainer));
export { NativeUIPopup };
